# Luxsci.Api.EmailApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

| Method | HTTP request | Description |
|--------|--------------|-------------|
| [**CreateCustomBounceDomain**](EmailApi.md#createcustombouncedomain) | **POST** /account/{accountId}/bounce_domain |  |
| [**CreateDkim**](EmailApi.md#createdkim) | **POST** /account/{accountId}/dkim |  |
| [**DeleteDkim**](EmailApi.md#deletedkim) | **DELETE** /account/{accountId}/dkim/{domainName} |  |
| [**DeleteEmailAutoResponder**](EmailApi.md#deleteemailautoresponder) | **DELETE** /user/{username}/email/ar/{id} |  |
| [**GetDkimDetails**](EmailApi.md#getdkimdetails) | **GET** /account/{accountId}/dkim/{domainName} |  |
| [**GetDkimReport**](EmailApi.md#getdkimreport) | **GET** /account/{accountId}/dkim |  |
| [**GetEmailAutoResponders**](EmailApi.md#getemailautoresponders) | **GET** /user/{username}/email/ar |  |
| [**NewEmailAutoResponder**](EmailApi.md#newemailautoresponder) | **POST** /user/{username}/email/ar |  |
| [**RetrieveSecureLineRecipientListEncryptionData**](EmailApi.md#retrievesecurelinerecipientlistencryptiondata) | **POST** /user/{username}/email/compose/secureline/recipients |  |
| [**UpdateEmailForwarding**](EmailApi.md#updateemailforwarding) | **PUT** /user/{username}/email/forwarding |  |

<a name="createcustombouncedomain"></a>
# **CreateCustomBounceDomain**
> void CreateCustomBounceDomain (string accountId, string? cookie = null, CreateCustomBounceDomainRequest? createCustomBounceDomainRequest = null)



Add a new Custom Bounce Domain to the account.  The bounce domain must be a subdomain of the from domain in question, have DKIM configured already, and the DNS must already be a CNAME to any of the target domains listed in the Custom Bounce Domains user interface area. {{ACL: Account: Domains - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class CreateCustomBounceDomainExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new EmailApi(config);
            var accountId = "accountId_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var createCustomBounceDomainRequest = new CreateCustomBounceDomainRequest?(); // CreateCustomBounceDomainRequest? |  (optional) 

            try
            {
                apiInstance.CreateCustomBounceDomain(accountId, cookie, createCustomBounceDomainRequest);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling EmailApi.CreateCustomBounceDomain: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the CreateCustomBounceDomainWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    apiInstance.CreateCustomBounceDomainWithHttpInfo(accountId, cookie, createCustomBounceDomainRequest);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling EmailApi.CreateCustomBounceDomainWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **createCustomBounceDomainRequest** | [**CreateCustomBounceDomainRequest?**](CreateCustomBounceDomainRequest?.md) |  | [optional]  |

### Return type

void (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="createdkim"></a>
# **CreateDkim**
> void CreateDkim (string accountId, string? cookie = null, CreateDkimRequest? createDkimRequest = null)



Create a new DKIM configuration in your account. {{ACL: Account: Domains - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class CreateDkimExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new EmailApi(config);
            var accountId = "accountId_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var createDkimRequest = new CreateDkimRequest?(); // CreateDkimRequest? |  (optional) 

            try
            {
                apiInstance.CreateDkim(accountId, cookie, createDkimRequest);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling EmailApi.CreateDkim: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the CreateDkimWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    apiInstance.CreateDkimWithHttpInfo(accountId, cookie, createDkimRequest);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling EmailApi.CreateDkimWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **createDkimRequest** | [**CreateDkimRequest?**](CreateDkimRequest?.md) |  | [optional]  |

### Return type

void (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deletedkim"></a>
# **DeleteDkim**
> Authentication201Response DeleteDkim (string accountId, string domainName, string? cookie = null)



Remove a DKIM definition from your account. {{ACL: Account: Domains - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class DeleteDkimExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new EmailApi(config);
            var accountId = "accountId_example";  // string | 
            var domainName = "domainName_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.DeleteDkim(accountId, domainName);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling EmailApi.DeleteDkim: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the DeleteDkimWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.DeleteDkimWithHttpInfo(accountId, domainName);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling EmailApi.DeleteDkimWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **domainName** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | none |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deleteemailautoresponder"></a>
# **DeleteEmailAutoResponder**
> Authentication201Response DeleteEmailAutoResponder (string username, string id, string? cookie = null)



Delete an email auto-responder number `id` that belongs to the user. {{ACL:User Email - Auto-Responders}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class DeleteEmailAutoResponderExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new EmailApi(config);
            var username = "username_example";  // string | 
            var id = "id_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.DeleteEmailAutoResponder(username, id);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling EmailApi.DeleteEmailAutoResponder: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the DeleteEmailAutoResponderWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.DeleteEmailAutoResponderWithHttpInfo(username, id);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling EmailApi.DeleteEmailAutoResponderWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **id** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | \&quot;\&quot; |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getdkimdetails"></a>
# **GetDkimDetails**
> GetDkimDetails200Response GetDkimDetails (string accountId, string domainName, string? cookie = null)



Get information about a specific DKIM configuration. This is the same as the “Get DKIM Report,” except that it returns data for 1 specific domain.  {{ACL: Account: Domains - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetDkimDetailsExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new EmailApi(config);
            var accountId = "accountId_example";  // string | 
            var domainName = "domainName_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetDkimDetails200Response result = apiInstance.GetDkimDetails(accountId, domainName);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling EmailApi.GetDkimDetails: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetDkimDetailsWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetDkimDetails200Response> response = apiInstance.GetDkimDetailsWithHttpInfo(accountId, domainName);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling EmailApi.GetDkimDetailsWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **domainName** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetDkimDetails200Response**](GetDkimDetails200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The data will be a single object with the keys and values for the domain requested, as per the “Get DKIM Report” API call, above.  Note that for this call, the data is returned without an enclosing array, as there is always exactly 1 object in the response&#39; |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getdkimreport"></a>
# **GetDkimReport**
> GetDkimReport200Response GetDkimReport (string accountId, string? cookie = null)



Get information about your DKIM configurations. {{ACL: Account: Domains - Manage}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetDkimReportExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new EmailApi(config);
            var accountId = "accountId_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetDkimReport200Response result = apiInstance.GetDkimReport(accountId);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling EmailApi.GetDkimReport: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetDkimReportWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetDkimReport200Response> response = apiInstance.GetDkimReportWithHttpInfo(accountId);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling EmailApi.GetDkimReportWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetDkimReport200Response**](GetDkimReport200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The data field of the response is an array of all DKIM definitions in your account. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getemailautoresponders"></a>
# **GetEmailAutoResponders**
> GetEmailAutoResponders200Response GetEmailAutoResponders (string username, string? cookie = null)



Return all email auto-responders owned by this user. {{ACL:User Email - Auto-Responders}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetEmailAutoRespondersExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new EmailApi(config);
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetEmailAutoResponders200Response result = apiInstance.GetEmailAutoResponders(username);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling EmailApi.GetEmailAutoResponders: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetEmailAutoRespondersWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetEmailAutoResponders200Response> response = apiInstance.GetEmailAutoRespondersWithHttpInfo(username);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling EmailApi.GetEmailAutoRespondersWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetEmailAutoResponders200Response**](GetEmailAutoResponders200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | A successful response will return an array of objects, one for each auto-responder owned by this user. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="newemailautoresponder"></a>
# **NewEmailAutoResponder**
> NewEmailAutoResponder200Response NewEmailAutoResponder (string username, NewEmailAutoResponderRequest? newEmailAutoResponderRequest = null)



Create a new email auto-responer. {{ACL:User Email - Auto-Responders}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class NewEmailAutoResponderExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new EmailApi(config);
            var username = "username_example";  // string | 
            var newEmailAutoResponderRequest = new NewEmailAutoResponderRequest?(); // NewEmailAutoResponderRequest? |  (optional) 

            try
            {
                NewEmailAutoResponder200Response result = apiInstance.NewEmailAutoResponder(username, newEmailAutoResponderRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling EmailApi.NewEmailAutoResponder: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the NewEmailAutoResponderWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<NewEmailAutoResponder200Response> response = apiInstance.NewEmailAutoResponderWithHttpInfo(username, newEmailAutoResponderRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling EmailApi.NewEmailAutoResponderWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **newEmailAutoResponderRequest** | [**NewEmailAutoResponderRequest?**](NewEmailAutoResponderRequest?.md) |  | [optional]  |

### Return type

[**NewEmailAutoResponder200Response**](NewEmailAutoResponder200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | A successful response will return the unique ID of the created auto-responder. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="retrievesecurelinerecipientlistencryptiondata"></a>
# **RetrieveSecureLineRecipientListEncryptionData**
> RetrieveSecureLineRecipientListEncryptionData200Response RetrieveSecureLineRecipientListEncryptionData (string username, string? cookie = null, RetrieveSecureLineRecipientListEncryptionDataRequest? retrieveSecureLineRecipientListEncryptionDataRequest = null)



When composing an email message, you may have a list of recipients and want to know what kind of encryption, if any, would be used for each recipient when it is finally sent out with SecureLine encryption. E.g. this can be used to (a) inform the sender of what encryption will be used, and (b) to discover ahead of time if there are some recipients for which a message cannot yet be encrypted (possible, for example, if SecureLine Escrow is setup to use question and answer authentication without a default fall-back question and answer).  It is good to use this method before sending an encrypted message – so you can modify your recipient list and/or add additional required encryption information before sending.  Note: This is a RPC-style call and hence uses a POST method even though we are “getting data”. We are interacting with the system rather than querying a specific resource. {{ACL: User Email - Sending}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class RetrieveSecureLineRecipientListEncryptionDataExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new EmailApi(config);
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var retrieveSecureLineRecipientListEncryptionDataRequest = new RetrieveSecureLineRecipientListEncryptionDataRequest?(); // RetrieveSecureLineRecipientListEncryptionDataRequest? |  (optional) 

            try
            {
                RetrieveSecureLineRecipientListEncryptionData200Response result = apiInstance.RetrieveSecureLineRecipientListEncryptionData(username, cookie, retrieveSecureLineRecipientListEncryptionDataRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling EmailApi.RetrieveSecureLineRecipientListEncryptionData: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the RetrieveSecureLineRecipientListEncryptionDataWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<RetrieveSecureLineRecipientListEncryptionData200Response> response = apiInstance.RetrieveSecureLineRecipientListEncryptionDataWithHttpInfo(username, cookie, retrieveSecureLineRecipientListEncryptionDataRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling EmailApi.RetrieveSecureLineRecipientListEncryptionDataWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **retrieveSecureLineRecipientListEncryptionDataRequest** | [**RetrieveSecureLineRecipientListEncryptionDataRequest?**](RetrieveSecureLineRecipientListEncryptionDataRequest?.md) |  | [optional]  |

### Return type

[**RetrieveSecureLineRecipientListEncryptionData200Response**](RetrieveSecureLineRecipientListEncryptionData200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The response body for a successful request will contain a hash in the “data” field with one keyword, “recipients”. The value of “recipients” is a list. Each list element will be another list corresponding to one of your queried recipients. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updateemailforwarding"></a>
# **UpdateEmailForwarding**
> Authentication201Response UpdateEmailForwarding (string username, string? cookie = null, UpdateEmailForwardingRequest? updateEmailForwardingRequest = null)



This function allows you to alter the email forwarding (and denial/deletion) settings for the user. {{ACL:User Email - Forwarding}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class UpdateEmailForwardingExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new EmailApi(config);
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var updateEmailForwardingRequest = new UpdateEmailForwardingRequest?(); // UpdateEmailForwardingRequest? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.UpdateEmailForwarding(username, cookie, updateEmailForwardingRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling EmailApi.UpdateEmailForwarding: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the UpdateEmailForwardingWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.UpdateEmailForwardingWithHttpInfo(username, cookie, updateEmailForwardingRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling EmailApi.UpdateEmailForwardingWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **updateEmailForwardingRequest** | [**UpdateEmailForwardingRequest?**](UpdateEmailForwardingRequest?.md) |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | \&quot;\&quot; |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

