# Luxsci.Api.ServersApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

| Method | HTTP request | Description |
|--------|--------------|-------------|
| [**GetServerStatus**](ServersApi.md#getserverstatus) | **GET** /account/{accountId}/server/{serverId} |  |
| [**GetServers**](ServersApi.md#getservers) | **GET** /account/{accountId}/servers |  |
| [**ServerEmptyAllEmailQueues**](ServersApi.md#serveremptyallemailqueues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues/all |  |
| [**ServerEmptyEmailQueues**](ServersApi.md#serveremptyemailqueues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues |  |
| [**SetServerSendngRate**](ServersApi.md#setserversendngrate) | **POST** /account/{accountId}/server/{serverId}/sending_rate |  |

<a name="getserverstatus"></a>
# **GetServerStatus**
> GetServerStatus200Response GetServerStatus (string accountId, string serverId, string? cookie = null)



This report allows you to retrieve specific current status of a specific server. This request will actually directly interrogate the server for some of this information; in situations where the server is overloaded or down or very slow, *this API will fail.*  {{ACL: Account: Servers - Report}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetServerStatusExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new ServersApi(config);
            var accountId = "accountId_example";  // string | 
            var serverId = "serverId_example";  // string | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetServerStatus200Response result = apiInstance.GetServerStatus(accountId, serverId);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling ServersApi.GetServerStatus: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetServerStatusWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetServerStatus200Response> response = apiInstance.GetServerStatusWithHttpInfo(accountId, serverId);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling ServersApi.GetServerStatusWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **serverId** | **string** | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetServerStatus200Response**](GetServerStatus200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | Server information. The data field in the JSON response has all of the keywords defined in the “Server List” command, above, as well as additional keywords. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getservers"></a>
# **GetServers**
> GetServers200Response GetServers (string accountId, string? cookie = null)



This report allows you to retrieve general information about all of the dedicated servers associated with your account. {{ACL: Account: Servers - Report}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetServersExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new ServersApi(config);
            var accountId = "accountId_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetServers200Response result = apiInstance.GetServers(accountId);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling ServersApi.GetServers: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetServersWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetServers200Response> response = apiInstance.GetServersWithHttpInfo(accountId);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling ServersApi.GetServersWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetServers200Response**](GetServers200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | List of servers. The data field in the JSON response is a list of hashes, one for every server. This list will be empty if your account does not have any dedicated servers. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="serveremptyallemailqueues"></a>
# **ServerEmptyAllEmailQueues**
> void ServerEmptyAllEmailQueues (string accountId, string serverId, string? cookie = null)



This command allows you to remove all email messages that are queued.  These are the mail_queue_trying and mail_queue_unprocessed messages returned by the server status call.  Messages that have not yet been processed will be deleted by this call. 

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class ServerEmptyAllEmailQueuesExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new ServersApi(config);
            var accountId = "accountId_example";  // string | 
            var serverId = "serverId_example";  // string | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                apiInstance.ServerEmptyAllEmailQueues(accountId, serverId);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling ServersApi.ServerEmptyAllEmailQueues: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the ServerEmptyAllEmailQueuesWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    apiInstance.ServerEmptyAllEmailQueuesWithHttpInfo(accountId, serverId);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling ServersApi.ServerEmptyAllEmailQueuesWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **serverId** | **string** | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

void (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | Simple success response. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="serveremptyemailqueues"></a>
# **ServerEmptyEmailQueues**
> void ServerEmptyEmailQueues (string accountId, string serverId, string? cookie = null)



This command allows you to remove all email messages that are queued and trying to be delivered to recipients.  These are the mail_queue_trying messages returned by the server status call.  Messages that have not yet been processed are not deleted. 

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class ServerEmptyEmailQueuesExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new ServersApi(config);
            var accountId = "accountId_example";  // string | 
            var serverId = "serverId_example";  // string | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                apiInstance.ServerEmptyEmailQueues(accountId, serverId);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling ServersApi.ServerEmptyEmailQueues: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the ServerEmptyEmailQueuesWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    apiInstance.ServerEmptyEmailQueuesWithHttpInfo(accountId, serverId);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling ServersApi.ServerEmptyEmailQueuesWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **serverId** | **string** | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

void (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | Simple success response. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="setserversendngrate"></a>
# **SetServerSendngRate**
> void SetServerSendngRate (string accountId, string serverId, string? cookie = null, SetServerSendngRateRequest? setServerSendngRateRequest = null)



This command allows you to update the email processing rate limits for this server.  These rate limits govern the rate at which messages are processed and delivered to the queues for delivery to recipients, for IP Warmup purposes.  These settings to not impact messages already processed trying to be delivered to recipients.

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class SetServerSendngRateExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new ServersApi(config);
            var accountId = "accountId_example";  // string | 
            var serverId = "serverId_example";  // string | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var setServerSendngRateRequest = new SetServerSendngRateRequest?(); // SetServerSendngRateRequest? |  (optional) 

            try
            {
                apiInstance.SetServerSendngRate(accountId, serverId, cookie, setServerSendngRateRequest);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling ServersApi.SetServerSendngRate: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the SetServerSendngRateWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    apiInstance.SetServerSendngRateWithHttpInfo(accountId, serverId, cookie, setServerSendngRateRequest);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling ServersApi.SetServerSendngRateWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **serverId** | **string** | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. |  |
| **cookie** | **string?** |  | [optional]  |
| **setServerSendngRateRequest** | [**SetServerSendngRateRequest?**](SetServerSendngRateRequest?.md) |  | [optional]  |

### Return type

void (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | Simple success response. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

